Code Reviews with Gerrit
========================

Sahara uses the `Gerrit`_ tool to review proposed code changes. The review
site is https://review.openstack.org.

Gerrit is a complete replacement for Github pull requests. `All Github pull
requests to the Sahara repository will be ignored`.

See `Development Workflow`_ for information about how to get
started using Gerrit.

.. _Gerrit: http://code.google.com/p/gerrit
.. _Development Workflow: https://docs.openstack.org/infra/manual/developers.html#development-workflow
